<?php

/* $Id: persian-utf-8.inc.php,v 2.75 2005/06/12 10:10:01 swix Exp $ */
/*
Persian(Farsi) translation by : Bornis Group
www.BornisGroup.com
info@BornisGroup.com
*/
$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'rtl'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'Tahoma, verdana, arial, helvetica, sans-serif';
$right_font_family = '"Windows UI", Tahoma, verdana, arial, helvetica, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('بايت', 'كيلوبايت', 'مگا بايت', 'گيگا بايت', 'ترابايت', 'پتا بايت', 'اگزا بايت');

$day_of_week = array('يكشنبه', 'دوشنبه', 'سه‌شنبه', 'چهارشنبه', 'پنج‌شنبه', 'جمعه', 'شنبه');
$month = array('ژانويه', 'فوريه', 'مارس', 'آوريل', 'مي', 'ژوئن', 'جولاي', 'آگوست', 'سپتامبر', 'اكتبر', 'نوامبر', 'دسامبر');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d %B %Y ساعت %I:%M %p';
$timespanfmt = '%s days, %s hours, %s minutes and %s seconds'; //to translate

$strAccessDenied = 'دسترسي مجاز نيست';
$strAction = 'عمل';
$strAddDeleteColumn = 'اضافه يا حذف ستونها';
$strAddDeleteRow = 'اضافه/حذف معيارها';
$strAddNewField = 'افزودن ستون جديد';
$strAddSearchConditions = 'افزودن شرايط جستجو (بدنه شرط "where"):';
$strAddUserMessage = 'شما يك كاربر جديد اضافه كرديد.';
$strAddUser = 'افزودن يك كاربر جديد';
$strAffectedRows = 'سطرهاي تحت تاثير واقع‌شده:';
$strAfterInsertBack = 'برو به صفحه قبل';
$strAfterInsertNewInsert = 'درج يك سطر جديد ديگر';
$strAfter = 'بعد از %s';
$strAllTableSameWidth = 'نمايش همه جدولها با عرض يكسان؟';
$strAll = 'همه';
$strAlterOrderBy = 'تغيير جدول مرتب شده با';
$strAnalyzeTable = 'تحليل جدول';
$strAnd = 'و';
$strAnIndex = 'يك فهرست در %s اضافه گرديد.';
$strAnyHost = 'همه ميزبانها';
$strAnyUser = 'همه كاربران';
$strAny = 'همه';
$strAPrimaryKey = 'يك كليد اصلي در %s اضافه شد';
$strAscending = 'صعودي';
$strAtBeginningOfTable = 'در ابتداي جدول';
$strAtEndOfTable = 'در انتهاي جدول';
$strAttr = 'ويژگيها';

$strBack = 'بازگشت';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = 'دودويي';
$strBrowse = 'مشاهده';
$strBzip = '"bzipped"';

$strCantLoadRecodeIconv = 'بارگذاري iconv يا  recode extension كه براي تبديل مجموعه كاراكترها لازم است ، مقدور نمي‌باشد، php را براي اجازه استفاده از آنها تنظيم كرده و يا تبديل مجموعه كاراكترها (charset conversion) را در phpMyAdmin غيرفعال نماييد.';
$strCantRenameIdxToPrimary = 'بازناميدن فهرست به PRIMARY مقدور نمي‌باشد!';
$strCarriage = 'رفتن به سر سطر: \\r';
$strChangeDisplay = 'ستون را براي نمايش انتخاب نماييد';
$strChangePassword = 'تغيير اسم رمز';
$strChange = 'تغيير';
$strCharsetOfFile = 'مجموعه كاراكترهاي پرونده:';
$strCheckAll = 'انتخاب همه';
$strCheckTable = 'بررسي جدول';
$strChoosePage = 'لطفا يك صفحه را براي ويرايش انتخاب نماييد';
$strColComFeat = 'نمايش توضيحات ستون';
$strColumnNames = 'نام ستونها';
$strComments = 'توضيحات';
$strCompleteInserts = 'تمام وروديها';
$strCompression = 'فشرده‌سازي';
$strConfigFileError = 'phpMyAdmin قادر به خواندن پرونده تنظيمات نمي‌باشد!<br />اين ممكن است به خاطر وجود يك مشكل دستوري و يا پيدانشدن پرونده توسط php باشد.<br />لطفا پرونده تنظميات را مستقيما توسط پيوند زير صدا زده و پيغام(هاي) خطاي php كه دريافت مي‌كنيد را بخوانيد. در اكثر موارد يك علامت نقل قول (" \' ") يا ويرگول‌نقطه (" ; ") در جايي وجود ندارد.<br />اگر يك صفحه خالي دريافت كرديد ، همه چيز درست است.';
$strConfigureTableCoord = 'لطفا مختصات جدول %s را تنظيم كنيد';
$strCopyTableOK = 'جدول %s به %s كپي شد.';
$strCopyTable = 'كپي كردن جدول به (پايگاه داده<b>.</b>جدول):';
$strCreateIndexTopic = 'ساخت فهرست جديد';
$strCreateIndex = 'ساخت يك فهرست در&nbsp;%s&nbsp;ستون';
$strCreateNewDatabase = 'ساخت پايگاه داده جديد';
$strCreateNewTable = 'ساخت جدول جديد در پايگاه داده %s';
$strCreatePage = 'ساخت يك صفحه جديد';
$strCreatePdfFeat = 'ساخت PDFs';
$strCreate = 'ساختن';
$strCriteria = 'معيارها';

$strDatabaseHasBeenDropped = 'پايگاه داده %s حذف گرديد.';
$strDatabasesStats = 'آمار پايگاههاي داده';
$strDatabases = 'پايگاههاي داده';
$strDatabase = 'پايگاه داده';
$strDataDict = 'فرهنگ داده‌ها';
$strDataOnly = 'فقط داده‌ها';
$strData = 'داده';
$strDefault = 'پيش‌فرض';
$strDeletedRows = 'سطرهاي حذف‌شده :';
$strDeleted = 'سطر حذف گرديد .';
$strDelete = 'حذف';
$strDescending = 'نزولي';
$strDisabled = 'غيرفعال';
$strDisplayFeat = 'نمايش خصوصيات';
$strDisplayOrder = 'ترتيب نمايش:';
$strDisplayPDF = 'نمايش الگوي PDF';
$strDoAQuery = 'انجام يك "پرس و جو با نمونه" (wildcard: "%")';
$strDocu = 'مستندات';
$strDoYouReally = 'آيا مطمئن هستيد ';
$strDrop = 'حذف';
$strDumpingData = 'حذف داده‌هاي جدول';
$strDumpXRows = 'حذف %s سطر(ها) ابتدا از سطر شماره %s.';
$strDynamic = 'پويا';

$strEditPDFPages = 'ويرايش صفحات PDF';
$strEditPrivileges = 'ويرايش امتيازات';
$strEdit = 'ويرايش';
$strEffective = 'موثر';
$strEmptyResultSet = 'MySQL يك نتيجه خالي داد. (مثلا 0 سطر).';
$strEmpty = 'خالي كردن';
$strEnabled = 'فعال';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEnd = 'انتها';
$strEnglishPrivileges = ' نكته : نام امتيازات MySQL به زبان انگليسي بيان مي‌شود .';
$strError = 'خطا';
$strExplain = 'شرح دادن SQL';
$strExport = 'صدور';
$strExtendedInserts = 'وروديهاي تمديدشده';
$strExtra = 'اضافي';

$strFieldHasBeenDropped = 'ستون %s حذف گرديد';
$strFieldsEmpty = ' تعداد ستونها خالي است! ';
$strFieldsEnclosedBy = 'ستونهاي درميان‌گرفته با';
$strFieldsEscapedBy = 'ستونهاي جداشده با';
$strFieldsTerminatedBy = 'ستونهاي منتهي به';
$strFields = 'ستونها';
$strField = 'ستون';
$strFixed = 'fixed';
$strFlushTable = 'Flush the table ("FLUSH")';
$strFormat = 'قالب';
$strFormEmpty = 'مقداري در فرم وارد نشده !';
$strFullText = 'كاملا متن';
$strFunction = 'تابع';

$strGenBy = 'توليد‌شده توسط';
$strGenTime = 'زمان توليد';
$strGo = 'تاييد';
$strGzip = '"gzipped"';

$strHasBeenAltered = 'تغيير داده‌شد.';
$strHasBeenCreated = 'ساخته شد.';
$strHaveToShow = 'شما حذاقل بايد يك ستون را براي نمايش انتخاب نماييد';
$strHomepageOfficial = 'صفحه خانه رسمي phpMyAdmin';
$strHome = 'خانه';
$strHostEmpty = 'نام ميزبان خالي است!';
$strHost = 'ميزبان';

$strIdxFulltext = 'كاملا متن';
$strIfYouWish = 'اگر مي‌خواهيد كه فقط بعضي از ستونهاي جدول را بارگذاري نماييد ، ليست ستونها را با كاما از هم جدا نماييد.';
$strIgnore = 'Ignore';
$strImportDocSQL = 'وارد كردن پرونده‌هاي docSQL';
$strIndexes = 'فهرست‌ها';
$strIndexHasBeenDropped = 'فهرست %s حذف گرديد';
$strIndexName = 'اسم فهرست&nbsp;:';
$strIndexType = 'نوع فهرست&nbsp;:';
$strIndex = 'فهرست';
$strInsecureMySQL = 'پرونده پيكربندي شما حاوي تنظيماتي است (كاربر root بدون اسم رمز) كه مرتبط با حساب پيش‌فرض MySQL مي‌باشد. اجراي MySQL با اين پيش‌فرض باعث ورود غيرمجاز مي‌شود ، و شما بايد اين حفره امنيتي را ذرست كنيد.';
$strInsertAsNewRow = 'درج به عنوان يك سطر جديد';
$strInsertedRows = 'سطرهاي درج‌شده:';
$strInsertNewRow = 'درج سطر جديد';
$strInsertTextfiles = 'درج داده‌ها از يك پرونده متني در جدول';
$strInsert = 'درج';
$strInstructions = 'راهنمايي';
$strInUse = 'in use';

$strKeepPass = 'عدم تغيير اسم رمز';
$strKeyname = 'Keyname';
$strKill = 'Kill';

$strLengthSet = 'طول/مقادير*';
$strLimitNumRows = 'تعداد سطرها در هر صفحه';
$strLineFeed = 'تعويض خط: \\n';
$strLinesTerminatedBy = 'خطوط منتهي به';
$strLinkNotFound = 'پيوند پيدا نشد';
$strLinksTo = 'پيوند به';
$strLocationTextfile = 'محل پرونده متني';
$strLogin = 'ورود';
$strLogout = 'خروج';
$strLogPassword = 'اسم رمز:';
$strLogUsername = 'نام كاربر:';

$strModifications = 'اصلاحات ذخيره گرديد';
$strModifyIndexTopic = 'اصلاح يك فهرست';
$strModify = 'اصلاح';
$strMoveTableOK = 'جدول %s به %s انتقال داده‌شد.';
$strMoveTable = 'انتقال جدول به (پايگاه داده<b>.</b>جدول):';
$strMySQLCharset = 'مجموع كاراكترهاي MySQL';
$strMySQLReloaded = 'MySQL مجددا بارگذاري شد.';
$strMySQLSaid = 'پيغام MySQL :';
$strMySQLServerProcess = 'MySQL %pma_s1% اجراشده در ميزبان %pma_s2% توسط %pma_s3%';
$strMySQLShowProcess = 'نمايش فرايندها';
$strMySQLShowStatus = 'نمايش اطلاعات MySQL';
$strMySQLShowVars = 'نمايش متغيرهاي سيستمي MySQL';

$strName = 'اسم';
$strNext = 'بعد';
$strNoDatabases = 'No databases';
$strNoDescription = 'no Description';
$strNoDropDatabases = 'دستور "DROP DATABASE" غيرفعال مي‌باشد.';
$strNoIndex = 'هيچ فهرستي تعريف‌نشده‌است!';
$strNone = 'خير';
$strNoPassword = 'بدون اسم رمز';
$strNoPhp = 'بدون كد PHP';
$strNoQuery = 'No SQL query!';
$strNoTablesFound = 'در اين پايگاه داده هيچ جدولي وجود ندارد .';
$strNotNumber = 'اين يك عدد نيست!';
$strNotOK = 'not OK';
$strNotSet = 'جدول <b>%s</b> وجود ندارد و يا در %s تنظيم نشده‌است';
$strNotValidNumber = ' يك شماره سطر صحيح نيست!';
$strNoUsersFound = 'هيچ كاربري وچود ندارد.';
$strNo = 'خير';
$strNull = 'خالي';
$strNumTables = 'جدولها';

$strOftenQuotation = 'اغلب علامت نقل قول. اختياري به اين معني است كه فقط ستونهاي char و varchar توسط كاراكتر "enclosed by" درميان گرفته‌ميشوند.';
$strOK = 'تاييد';
$strOperations = 'عمليات';
$strOptimizeTable = 'بهينه‌سازي جدول';
$strOptionalControls = 'اختياري. كنترل چگونگي خواندن و نوشتن كاراكترهاي خاص.';
$strOptionally = 'اختياري';
$strOr = 'يا';

$strPageNumber = 'شماره صفحه:';
$strPasswordEmpty = 'اسم رمز خالي است!';
$strPasswordNotSame = 'اسم رمزها مانند هم نمي‌باشد!';
$strPassword = 'اسم رمز';
$strPdfInvalidTblName = 'جدول "%s" وجود ندارد!';
$strPdfNoTables = 'No tables';
$strPersian = 'فارسي';
$strPHPVersion = 'نسخه PHP';
$strPhp = 'ساخت كد PHP';
$strPmaDocumentation = 'مستندات phpMyAdmin';
$strPos1 = 'شروع';
$strPrevious = 'قبل';
$strPrimaryKeyHasBeenDropped = 'كليد اصلي حذف گرديد';
$strPrimaryKeyName = 'نام كليد اصلي بايد PRIMARY باشد !';
$strPrimaryKeyWarning = '(<b>فقط و فقط بايد</b> "PRIMARY" نام يك كليد اصلي باشد!)';
$strPrimary = 'اصلي';
$strPrintView = 'نماي چاپ';
$strPrint = 'چاپ';
$strPrivileges = 'امتيازات';
$strPutColNames = 'قراردادن نام ستونها در اولين سطر';

$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQBE = 'پرس و جو';
$strQueryOnDb = 'پرس و جوي SQL از پايگاه داده <b>%s</b>:';

$strRecords = 'سطرها';
$strRelationNotWorking ='امكانات اضافي براي كاركردن با جدولهاي پيوندي غيرفعال شده‌است . براي پيداكردن دليل آن %sاينجا%s را بزنيد .';
$strReloadMySQL = 'بار كردن مجدد MySQL';
$strRenameTableOK = 'جدول %s به %s تغيير نام داده‌شد';
$strRenameTable = 'بازناميدن جدول به';
$strRepairTable = 'مرمت جدول';
$strReplaceTable = 'جايگزيني داده‌هاي جدول با پرونده';
$strReplace = 'جايگذاري';
$strReset = 'Reset';
$strReType = 'تكرار';
$strRevokeMessage = 'شما امتيازات %s را ابطال كرديد';
$strRevoke = 'ابطال';
$strRowLength = 'طول سطر';
$strRowsFrom = 'سطر(ها) ابتدا از سطر شماره ';
$strRowSize = ' اندازه سطر ';
$strRowsModeHorizontal = 'افقي';
$strRowsModeVertical = 'عمودي';
$strRowsStatistic = 'آمار سطرها';
$strRows = 'سطرها';
$strRunning = 'در ميزبان %s';
$strRunQuery = 'Submit Query';
$strRunSQLQuery = 'اجراي پرس و جو(ها)ي SQL در پايگاه‌داده %s';

$strSave = 'ذخيره';
$strSearchFormTitle = 'جستجو در پايگاه‌داده';
$strSearchInTables = 'در جدول(هاي) :';
$strSearchNeedle = 'كلمه(ها) يا مقدار(ها) براي جستجو (wildcard: "%"):';
$strSearchOption1 = 'حداقل يكي از كلمات';
$strSearchOption2 = 'تمامي كلمات';
$strSearchOption3 = 'عبارت كامل';
$strSearchOption4 = 'بعنوان مبين منظم(as regular expression)';
$strSearchResultsFor = 'نتيجه جستجوي "<i>%s</i>" %s:';
$strSearchType = 'نوع جستجو :';
$strSearch = 'جستجو';
$strSelectADb = 'لطفا يك پايگاه داده را انتخاب نماييد.';
$strSelectAll = 'انتخاب همه';
$strSelectFields = 'ستونها را انتخاب نماييد (حداقل يكي)';
$strSelectNumRows = 'in query';
$strSelectTables = 'Select Tables';
$strSend = 'ذخيره به صورت پرونده';
$strServerVersion = 'نسخه سرور';
$strServer = 'سرور';
$strSetEnumVal = 'اگر نوع ستون "enum" يا "set" مي‌باشد ، لطفا براي ورود مقادير از اين قالب استفاده نماييد : \'a\',\'b\',\'c\'...<br /> اگر احتياج داشتيد كه از علامت مميز برعكس(بك‌اسلش) (" \ ") يا نقل‌قول تكي (" \' ") در آن مقادير استفاده نماييد ، قبل از آنها علامت (" \ ") را بگذاريد<br /> (براي مثال\'\\\\xyz\' يا \'a\\\'b\')';
$strShowAll = 'نمايش همه';
$strShowColor = 'نمايش رنگ';
$strShowGrid = 'Show grid';
$strShowingRecords = 'Showing rows';
$strShowPHPInfo = 'نمايش اطلاعات PHP';
$strShowTableDimension = 'نمايش ابعاد جدولها';
$strShowTables = 'نمايش جدولها';
$strShowThisQuery = ' نمايش دوباره اين پرس و جو در اينجا ';
$strShow = 'نمايش';
$strSingly = '(تنها)';
$strSize = 'اندازه';
$strSort = 'ترتيب';
$strSpaceUsage = 'فضاي استفاده‌شده';
$strSplitWordsWithSpace = 'كلمات با علامت فاصله (" ") جدا مي‌شوند.';
$strSQLQuery = 'پرس و جوي SQL';
$strSQLResult = 'نتيجه SQL';
$strSQL = 'SQL';
$strStatement = 'شرج';
$strStrucCSV = 'داده‌هاي CSV';
$strStrucData = 'ساختار و داده‌ها';
$strStrucDrop = 'افزودن \'جدول حذف‌شده\'';
$strStrucExcelCSV = 'CSV براي داده‌هاي MS Excel';
$strStrucOnly = 'فقط ساختار';
$strStructPropose = 'پيشنهاد ساختار جدول';
$strStructure = 'ساختار';
$strSubmit = 'ارسال';
$strSuccess = 'پرس و جوي SQL شما با موفقيت اجرا گرديد';
$strSum = 'مجموع';

$strTableComments = 'توضيحات جدول';
$strTableEmpty = 'نام جدول وارد نشده‌است !';
$strTableHasBeenDropped = 'جدول %s حذف گرديد';
$strTableHasBeenEmptied = 'جدول %s خالي شد';
$strTableMaintenance = 'نگهداشت جدول';
$strTables = '%s جدول(ها)';
$strTableType = 'نوع جدول';
$strTable = 'جدول';
$strTheContent = 'محتويات پرونده شما قراداده‌شد.';
$strTotalUC = 'جمع كل';
$strTotal = 'جمع كل';
$strType = 'نوع';

$strUncheckAll = 'عدم انتخاب همه';
$strUnique = 'يكتا';
$strUnselectAll = 'عدم انتخاب همه';
$strUpdatePrivMessage = 'امتيازات %s به هنگام گرديد.';
$strUpdateProfileMessage = 'تنظيمات به هنگام گرديد.';
$strUpdateQuery = 'به‌هنگام سازي پرس و جو';
$strUsage = 'استفاده';
$strUseBackquotes = 'قراردادن نام جدولها و ستونها بين علامت نقل‌قول (" \' ")';
$strUserEmpty = 'نام كاربر خالي است!';
$strUserName = 'نام كاربر';
$strUser = 'كاربر';
$strUseTables = 'بكارگيري جدولها';

$strValidateSQL = 'معتبرسازي SQL';
$strValue = 'مقدار';
$strViewDumpDB = 'نمايش الگوي پايگاه داده';
$strViewDump = 'نمايش الگوي جدول';

$strWebServerUploadDirectoryError = 'پوشه‌اي را كه براي انتقال فايل انتخاب كرده‌ايد قابل دسترسي نيست.';
$strWelcome = 'به %s خوش‌آمديد';
$strWithChecked = 'موارد انتخاب‌شده :';
$strWrongUser = 'نام كاربر/اسم رمز اشتباه است. دسترسي مجاز نيست.';

$strYes = 'بلي';

$strZip = '"zipped"';

// To translate:
$strAbortedClients = 'Aborted'; //to translate
$strAbsolutePathToDocSqlDir = 'Please enter the absolute path on webserver to docSQL directory'; //to translate
$strAccessDeniedExplanation = 'phpMyAdmin tried to connect to the MySQL server, and the server rejected the connection. You should check the host, username and password in config.inc.php and make sure that they correspond to the information given by the administrator of the MySQL server.'; //to translate
$strAddAutoIncrement = 'Add AUTO_INCREMENT value'; //to translate
$strAddConstraints = 'Add constraints';  //to translate
$strAddDropDatabase = 'Add DROP DATABASE'; //to translate
$strAddedColumnComment = 'Added comment for column'; //to translate
$strAddedColumnRelation = 'Added relation for column'; //to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strAddIntoComments = 'Add into comments'; //to translate
$strAddPrivilegesOnDb = 'Add privileges on the following database'; //to translate
$strAddPrivilegesOnTbl = 'Add privileges on the following table'; //to translate
$strAddToIndex = 'Add to index &nbsp;%s&nbsp;column(s)'; //to translate
$strAdministration = 'Administration'; //to translate
$strAfterInsertSame = 'Go back to this page';  //to translate
$strArabic = 'Arabic'; //to translate
$strArmenian = 'Armenian'; //to translate
$strAutodetect = 'Autodetect'; //to translate
$strAutomaticLayout = 'Automatic layout'; //to translate

$strBaltic = 'Baltic'; //to translate
$strBinaryDoNotEdit = 'Binary - do not edit'; //to translate
$strBookmarkAllUsers = 'Let every user access this bookmark'; //to translate
$strBookmarkDeleted = 'The bookmark has been deleted.'; //to translate
$strBookmarkLabel = 'Label'; //to translate
$strBookmarkOptions = 'Bookmark options';  //to translate
$strBookmarkQuery = 'Bookmarked SQL-query'; //to translate
$strBookmarkThis = 'Bookmark this SQL-query'; //to translate
$strBookmarkView = 'View only'; //to translate
$strBrowseForeignValues = 'Browse foreign values'; //to translate
$strBulgarian = 'Bulgarian'; //to translate
$strBzError = 'phpMyAdmin was unable to compress the dump because of a broken Bz2 extension in this php version. It is strongly recommended to set the <code>$cfg[\'BZipDump\']</code> directive in your phpMyAdmin configuration file to <code>FALSE</code>. If you want to use the Bz2 compression features, you should upgrade to a later php version. See php bug report %s for details.'; //to translate

$strCalendar = 'Calendar';  //to translate
$strCannotLogin = 'Cannot login to MySQL server'; //to translate
$strCantLoad = 'cannot load %s extension,<br />please check PHP Configuration'; //to translate
$strCantUseRecodeIconv = 'Can not use iconv nor libiconv nor recode_string function while extension reports to be loaded. Check your php configuration.'; //to translate
$strCardinality = 'Cardinality'; //to translate
$strCaseInsensitive = 'case-insensitive'; //to translate
$strCaseSensitive = 'case-sensitive'; //to translate
$strCentralEuropean = 'Central European'; //to translate
$strChangeCopyModeCopy = '... keep the old one.'; //to translate
$strChangeCopyMode = 'Create a new user with the same privileges and ...'; //to translate
$strChangeCopyModeDeleteAndReload = ' ... delete the old one from the user tables and reload the privileges afterwards.'; //to translate
$strChangeCopyModeJustDelete = ' ... delete the old one from the user tables.'; //to translate
$strChangeCopyModeRevoke = ' ... revoke all active privileges from the old one and delete it afterwards.'; //to translate
$strChangeCopyUser = 'Change Login Information / Copy User'; //to translate
$strCharset = 'Charset'; //to translate
$strCharsetsAndCollations = 'Character Sets and Collations'; //to translate
$strCharsets = 'Charsets'; //to translate
$strCheckOverhead = 'Check tables with overhead';  //to translate
$strCheckPrivs = 'Check Privileges'; //to translate
$strCheckPrivsLong = 'Check privileges for database &quot;%s&quot;.'; //to translate
$strCollation = 'Collation'; //to translate
$strColumnPrivileges = 'Column-specific privileges'; //to translate
$strCommand = 'Command'; //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strConnections = 'Connections'; //to translate
$strConstraintsForDumped = 'Constraints for dumped tables'; //to translate
$strConstraintsForTable = 'Constraints for table'; //to translate
$strCookiesRequired = 'Cookies must be enabled past this point.'; //to translate
$strCopyTableSameNames = 'Can\'t copy table to same one!'; //to translate
$strCouldNotKill = 'phpMyAdmin was unable to kill thread %s. It probably has already been closed.'; //to translate
$strCreationDates = 'Creation/Update/Check dates';  //to translate
$strCroatian = 'Croatian'; //to translate
$strCSVOptions = 'CSV options'; //to translate
$strCyrillic = 'Cyrillic'; //to translate
$strCzech = 'Czech'; //to translate
$strCzechSlovak = 'Czech-Slovak';  //to translate

$strDanish = 'Danish'; //to translate
$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDatabaseExportOptions = 'Database export options'; //to translate
$strDatabaseNoTable = 'This database contains no table!'; //to translate
$strDatabasesDropped = '%s databases have been dropped successfully.'; //to translate
$strDatabasesStatsDisable = 'Disable Statistics'; //to translate
$strDatabasesStatsEnable = 'Enable Statistics'; //to translate
$strDatabasesStatsHeavyTraffic = 'Note: Enabling the Database statistics here might cause heavy traffic between the webserver and the MySQL one.'; //to translate
$strDBComment = 'Database comment: '; //to translate
$strDBGContext = 'Context'; //to translate
$strDBGContextID = 'Context ID'; //to translate
$strDBGHits = 'Hits'; //to translate
$strDBGLine = 'Line'; //to translate
$strDBGMaxTimeMs = 'Max time, ms'; //to translate
$strDBGMinTimeMs = 'Min time, ms'; //to translate
$strDBGModule = 'Module'; //to translate
$strDBGTimePerHitMs = 'Time/Hit, ms'; //to translate
$strDBGTotalTimeMs = 'Total time, ms'; //to translate
$strDbPrivileges = 'Database-specific privileges'; //to translate
$strDBRename = 'Rename database to';  //to translate
$strDbSpecific = 'database-specific'; //to translate
$strDefaultValueHelp = 'For default values, please enter just a single value, without backslash escaping or quotes, using this format: a'; //to translate
$strDefragment = 'Defragment table';  //to translate
$strDelayedInserts = 'Use delayed inserts';  //to translate
$strDeleteAndFlush = 'Delete the users and reload the privileges afterwards.'; //to translate
$strDeleteAndFlushDescr = 'This is the cleanest way, but reloading the privileges may take a while.'; //to translate
$strDeleting = 'Deleting %s'; //to translate
$strDelOld = 'The current Page has References to Tables that no longer exist. Would you like to delete those References?'; //to translate
$strDescription = 'Description'; //to translate
$strDictionary = 'dictionary'; //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strDropSelectedDatabases = 'Drop Selected Databases'; //to translate
$strDropUsersDb = 'Drop the databases that have the same names as the users.'; //to translate
$strDumpSaved = 'Dump has been saved to file %s.'; //to translate

$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strEnglish = 'English'; //to translate
$strEstonian = 'Estonian'; //to translate
$strExcelEdition = 'Excel edition';  //to translate
$strExcelOptions = 'Excel options'; //to translate
$strExecuteBookmarked = 'Execute bookmarked query'; //to translate

$strFailedAttempts = 'Failed attempts'; //to translate
$strFileAlreadyExists = 'File %s already exists on server, change filename or check overwrite option.'; //to translate
$strFileCouldNotBeRead = 'File could not be read'; //to translate
$strFileNameTemplate = 'File name template'; //to translate
$strFileNameTemplateHelp = 'Use __DB__ for database name, __TABLE__ for table name and %sany strftime%s options for time specification, extension will be automagically added. Any other text will be preserved.'; //to translate
$strFileNameTemplateRemember = 'remember template'; //to translate
$strFlushPrivilegesNote = 'Note: phpMyAdmin gets the users\' privileges directly from MySQL\'s privilege tables. The content of these tables may differ from the privileges the server uses if manual changes have made to it. In this case, you should %sreload the privileges%s before you continue.'; //to translate

$strGeneralRelationFeat = 'General relation features'; //to translate
$strGeorgian = 'Georgian';  //to translate
$strGerman = 'German'; //to translate
$strGlobal = 'global'; //to translate
$strGlobalPrivileges = 'Global privileges'; //to translate
$strGlobalValue = 'Global value'; //to translate
$strGrantOption = 'Grant'; //to translate
$strGreek = 'Greek'; //to translate

$strHebrew = 'Hebrew'; //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strHungarian = 'Hungarian'; //to translate

$strIcelandic = 'Icelandic';  //to translate
$strId = 'ID'; //to translate
$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strIgnoringFile = 'Ignoring file %s'; //to translate
$strImportFiles = 'Import files'; //to translate
$strImportFinished = 'Import finished'; //to translate
$strInnodbStat = 'InnoDB Status'; //to translate
$strInsertedRowId = 'Inserted row id:'; //to translate
$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.'; //to translate
$strInternalRelations = 'Internal relations'; //to translate

$strJapanese = 'Japanese'; //to translate
$strJumpToDB = 'Jump to database &quot;%s&quot;.'; //to translate
$strJustDeleteDescr = 'The &quot;deleted&quot; users will still be able to access the server as usual until the privileges are reloaded.'; //to translate
$strJustDelete = 'Just delete the users from the privilege tables.'; //to translate

$strKorean = 'Korean'; //to translate

$strLandscape = 'Landscape'; //to translate
$strLatexCaption = 'Table caption'; //to translate
$strLatexContent = 'Content of table __TABLE__'; //to translate
$strLatexContinuedCaption = 'Continued table caption'; //to translate
$strLatexContinued = '(continued)'; //to translate
$strLatexIncludeCaption = 'Include table caption'; //to translate
$strLatexLabel = 'Label key'; //to translate
$strLaTeX = 'LaTeX'; //to translate
$strLaTeXOptions = 'LaTeX options'; //to translate
$strLatexStructure = 'Structure of table __TABLE__'; //to translate
$strLatvian = 'Latvian';  //to translate
$strLithuanian = 'Lithuanian'; //to translate
$strLoadExplanation = 'The best method is checked by default, but you can change if it fails.'; //to translate
$strLoadMethod = 'LOAD method'; //to translate
$strLocalhost = 'Local'; //to translate
$strLoginInformation = 'Login Information'; //to translate
$strLogServer = 'Server'; //to translate

$strMaximumSize = 'Maximum size: %s%s';  //to translate
$strMIME_available_mime = 'Available MIME-types'; //to translate
$strMIME_available_transform = 'Available transformations'; //to translate
$strMIME_description = 'Description'; //to translate
$strMIME_MIMEtype = 'MIME-type'; //to translate
$strMIME_nodescription = 'No Description is available for this transformation.<br />Please ask the author, what %s does.'; //to translate
$strMIME_transformation = 'Browser transformation'; //to translate
$strMIME_transformation_note = 'For a list of available transformation options and their MIME-type transformations, click on %stransformation descriptions%s'; //to translate
$strMIME_transformation_options_note = 'Please enter the values for transformation options using this format: \'a\',\'b\',\'c\'...<br />If you ever need to put a backslash ("\") or a single quote ("\'") amongst those values, backslashes it (for example \'\\\\xyz\' or \'a\\\'b\').'; //to translate
$strMIME_transformation_options = 'Transformation options'; //to translate
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strMIME_without = 'MIME-types printed in italics do not have a seperate transformation function'; //to translate
$strMoreStatusVars = 'More status variables'; //to translate
$strMoveTableSameNames = 'Can\'t move table to same one!'; //to translate
$strMultilingual = 'multilingual'; //to translate
$strMustSelectFile = 'You should select file which you want to insert.'; //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate

$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
$strNoDatabasesSelected = 'No databases selected.'; //to translate
$strNoExplain = 'Skip Explain SQL'; //to translate
$strNoFrames = 'phpMyAdmin is more friendly with a <b>frames-capable</b> browser.'; //to translate
$strNoIndexPartsDefined = 'No index parts defined!'; //to translate
$strNoModification = 'No change'; //to translate
$strNoOptions = 'This format has no options'; //to translate
$strNoPermission = 'The web server does not have permission to save the file %s.'; //to translate
$strNoPrivileges = 'No Privileges'; //to translate
$strNoRights = 'You don\'t have enough rights to be here right now!'; //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strNoSpace = 'Insufficient space to save the file %s.'; //to translate
$strNoValidateSQL = 'Skip Validate SQL'; //to translate
$strNumSearchResultsInTable = '%s match(es) inside table <i>%s</i>'; //to translate
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> match(es)'; //to translate

$strOperator = 'Operator';  //to translate
$strOverhead = 'Overhead'; //to translate
$strOverwriteExisting = 'Overwrite existing file(s)'; //to translate

$strPaperSize = 'Paper size'; //to translate
$strPartialText = 'Partial Texts'; //to translate
$strPasswordChanged = 'The Password for %s was changed successfully.'; //to translate
$strPdfDbSchema = 'Schema of the the "%s" database - Page %s'; //to translate
$strPerHour = 'per hour'; //to translate
$strPerMinute = 'per minute'; //to translate
$strPerSecond = 'per second'; //to translate
$strPhoneBook = 'phone book'; //to translate
$strPHP40203 = 'You are using PHP 4.2.3, which has a serious bug with multi-byte strings (mbstring). See PHP bug report 19404. This version of PHP is not recommended for use with phpMyAdmin.'; //to translate
$strPmaUriError = 'The <tt>$cfg[\'PmaAbsoluteUri\']</tt> directive MUST be set in your configuration file!'; //to translate
$strPolish = 'Polish';  //to translate
$strPortrait = 'Portrait'; //to translate
$strPrintViewFull = 'Print view (with full texts)'; //to translate
$strPrivDescAllPrivileges = 'Includes all privileges except GRANT.'; //to translate
$strPrivDescAlter = 'Allows altering the structure of existing tables.'; //to translate
$strPrivDescCreateDb = 'Allows creating new databases and tables.'; //to translate
$strPrivDescCreateTbl = 'Allows creating new tables.'; //to translate
$strPrivDescCreateTmpTable = 'Allows creating temporary tables.'; //to translate
$strPrivDescDelete = 'Allows deleting data.'; //to translate
$strPrivDescDropDb = 'Allows dropping databases and tables.'; //to translate
$strPrivDescDropTbl = 'Allows dropping tables.'; //to translate
$strPrivDescExecute = 'Allows running stored procedures; Has no effect in this MySQL version.'; //to translate
$strPrivDescFile = 'Allows importing data from and exporting data into files.'; //to translate
$strPrivDescGrant = 'Allows adding users and privileges without reloading the privilege tables.'; //to translate
$strPrivDescIndex = 'Allows creating and dropping indexes.'; //to translate
$strPrivDescInsert = 'Allows inserting and replacing data.'; //to translate
$strPrivDescLockTables = 'Allows locking tables for the current thread.'; //to translate
$strPrivDescMaxConnections = 'Limits the number of new connections the user may open per hour.'; //to translate
$strPrivDescMaxQuestions = 'Limits the number of queries the user may send to the server per hour.'; //to translate
$strPrivDescMaxUpdates = 'Limits the number of commands that change any table or database the user may execute per hour.'; //to translate
$strPrivDescProcess3 = 'Allows killing processes of other users.'; //to translate
$strPrivDescProcess4 = 'Allows viewing the complete queries in the process list.'; //to translate
$strPrivDescReferences = 'Has no effect in this MySQL version.'; //to translate
$strPrivDescReload = 'Allows reloading server settings and flushing the server\'s caches.'; //to translate
$strPrivDescReplClient = 'Gives the right to the user to ask where the slaves / masters are.'; //to translate
$strPrivDescReplSlave = 'Needed for the replication slaves.'; //to translate
$strPrivDescSelect = 'Allows reading data.'; //to translate
$strPrivDescShowDb = 'Gives access to the complete list of databases.'; //to translate
$strPrivDescShutdown = 'Allows shutting down the server.'; //to translate
$strPrivDescSuper = 'Allows connecting, even if maximum number of connections is reached; Required for most administrative operations like setting global variables or killing threads of other users.'; //to translate
$strPrivDescUpdate = 'Allows changing data.'; //to translate
$strPrivDescUsage = 'No privileges.'; //to translate
$strPrivilegesReloaded = 'The privileges were reloaded successfully.'; //to translate
$strProcesslist = 'Process list'; //to translate

$strQueryFrame = 'Query window'; //to translate
$strQuerySQLHistory = 'SQL-history'; //to translate
$strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.'; //to translate
$strQueryTime = 'Query took %01.4f sec'; //to translate
$strQueryType = 'Query type'; //to translate
$strQueryWindowLock = 'Do not overwrite this query from outside the window'; //to translate

$strReceived = 'Received'; //to translate
$strReferentialIntegrity = 'Check referential integrity:'; //to translate
$strRefresh = 'Refresh';  //to translate
$strRelationalSchema = 'Relational schema'; //to translate
$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strRelations = 'Relations'; //to translate
$strRelationView = 'Relation view'; //to translate
$strReloadFailed = 'MySQL reload failed.'; //to translate
$strReloadingThePrivileges = 'Reloading the privileges'; //to translate
$strRemoveSelectedUsers = 'Remove selected users'; //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
$strReplaceNULLBy = 'Replace NULL by'; //to translate
$strResourceLimits = 'Resource limits'; //to translate
$strRevokeAndDeleteDescr = 'The users will still have the USAGE privilege until the privileges are reloaded.'; //to translate
$strRevokeAndDelete = 'Revoke all active privileges from the users and delete them afterwards.'; //to translate
$strRomanian = 'Romanian';  //to translate
$strRowsModeFlippedHorizontal = 'horizontal (rotated headers)'; //to translate
$strRowsModeOptions = 'in %s mode and repeat headers after %s cells'; //to translate
$strRussian = 'Russian'; //to translate

$strSaveOnServer = 'Save on server in %s directory'; //to translate
$strScaleFactorSmall = 'The scale factor is too small to fit the schema on one page'; //to translate
$strSecretRequired = 'The configuration file now needs a secret passphrase (blowfish_secret).'; //to translate
$strSent = 'Sent'; //to translate
$strServerChoice = 'Server Choice'; //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strServerStatus = 'Runtime Information'; //to translate
$strServerStatusUptime = 'This MySQL server has been running for %s. It started up on %s.'; //to translate
$strServerTabProcesslist = 'Processes'; //to translate
$strServerTabVariables = 'Variables'; //to translate
$strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.'; //to translate
$strServerVars = 'Server variables and settings'; //to translate
$strSessionValue = 'Session value'; //to translate
$strShowDatadictAs = 'Data Dictionary Format'; //to translate
$strShowFullQueries = 'Show Full Queries'; //to translate
$strSimplifiedChinese = 'Simplified Chinese'; //to translate
$strSlovak = 'Slovak';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strSortByKey = 'Sort by key'; //to translate
$strSpanish = 'Spanish';  //to translate
$strSQLExportType = 'Export type';  //to translate
$strSQLOptions = 'SQL options'; //to translate
$strSQLParserBugMessage = 'There is a chance that you may have found a bug in the SQL parser. Please examine your query closely, and check that the quotes are correct and not mis-matched. Other possible failure causes may be that you are uploading a file with binary outside of a quoted text area. You can also try your query on the MySQL command line interface. The MySQL server error output below, if there is any, may also help you in diagnosing the problem. If you still have problems or if the parser fails where the command line interface succeeds, please reduce your SQL query input to the single query that causes problems, and submit a bug report with the data chunk in the CUT section below:'; //to translate
$strSQLParserUserError = 'There seems to be an error in your SQL query. The MySQL server error output below, if there is any, may also help you in diagnosing the problem'; //to translate
$strSQPBugInvalidIdentifer = 'Invalid Identifer'; //to translate
$strSQPBugUnclosedQuote = 'Unclosed quote'; //to translate
$strSQPBugUnknownPunctuation = 'Unknown Punctuation String'; //to translate
$strStatCheckTime = 'Last check'; //to translate
$strStatCreateTime = 'Creation'; //to translate
$strStatUpdateTime = 'Last update'; //to translate
$strStatus = 'Status'; //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strSwedish = 'Swedish'; //to translate
$strSwitchToTable = 'Switch to copied table'; //to translate

$strTableHasBeenFlushed = 'Table %s has been flushed'; //to translate
$strTableOfContents = 'Table of contents'; //to translate
$strTableOptions = 'Table options'; //to translate
$strTableStructure = 'Table structure for table'; //to translate
$strTakeIt = 'take it';  //to translate
$strTblPrivileges = 'Table-specific privileges'; //to translate
$strTextAreaLength = ' Because of its length,<br /> this field might not be editable '; //to translate
$strThai = 'Thai'; //to translate
$strTheContents = 'The contents of the file replaces the contents of the selected table for rows with identical primary or unique key.'; //to translate
$strTheme = 'Theme / Style';  //to translate
$strTheTerminator = 'The terminator of the fields.'; //to translate
$strThisHost = 'This Host'; //to translate
$strThisNotDirectory = 'This was not a directory'; //to translate
$strThreadSuccessfullyKilled = 'Thread %s was successfully killed.'; //to translate
$strTime = 'Time'; //to translate
$strToggleScratchboard = 'Toggle scratchboard'; //to translate
$strTraditionalChinese = 'Traditional Chinese'; //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strTraffic = 'Traffic'; //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strTransformation_image_jpeg__inline = 'Displays a clickable thumbnail; options: width,height in pixels (keeps the original ratio)'; //to translate
$strTransformation_image_jpeg__link = 'Displays a link to this image (direct blob download, i.e.).'; //to translate
$strTransformation_image_png__inline = 'See image/jpeg: inline'; //to translate
$strTransformation_text_plain__dateformat = 'Takes a TIME, TIMESTAMP or DATETIME field and formats it using your local dateformat. First option is the offset (in hours) which will be added to the timestamp (Default: 0). Second option is a different dateformat according to the parameters available for PHPs strftime().'; //to translate
$strTransformation_text_plain__external = 'LINUX ONLY: Launches an external application and feeds the fielddata via standard input. Returns standard output of the application. Default is Tidy, to pretty print HTML code. For security reasons, you have to manually edit the file libraries/transformations/text_plain__external.inc.php and insert the tools you allow to be run. The first option is then the number of the program you want to use and the second option are the parameters for the program. The third parameter, if set to 1 will convert the output using htmlspecialchars() (Default is 1). A fourth parameter, if set to 1 will put a NOWRAP to the content cell so that the whole output will be shown without reformatting (Default 1)'; //to translate
$strTransformation_text_plain__formatted = 'Preserves original formatting of the field. No Escaping is done.'; //to translate
$strTransformation_text_plain__imagelink = 'Displays an image and a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is the width in pixels, third is the height.'; //to translate
$strTransformation_text_plain__link = 'Displays a link, the field contains the filename; first option is a prefix like "http://domain.com/", second option is a title for the link.'; //to translate
$strTransformation_text_plain__substr = 'Only shows part of a string. First option is an offset to define where the output of your text starts (Default 0). Second option is an offset how much text is returned. If empty, returns all the remaining text. The third option defines which chars will be appended to the output when a substring is returned (Default: ...) .'; //to translate
$strTruncateQueries = 'Truncate Shown Queries'; //to translate
$strTurkish = 'Turkish'; //to translate

$strUkrainian = 'Ukrainian'; //to translate
$strUnicode = 'Unicode'; //to translate
$strUnknown = 'unknown'; //to translate
$strUpdComTab = 'Please see Documentation on how to update your Column_comments Table'; //to translate
$strUpgrade = 'You should upgrade to %s %s or later.'; //to translate
$strUseHostTable = 'Use Host Table'; //to translate
$strUserAlreadyExists = 'The user %s already exists!'; //to translate
$strUserNotFound = 'The selected user was not found in the privilege table.'; //to translate
$strUserOverview = 'User overview'; //to translate
$strUsersDeleted = 'The selected users have been deleted successfully.'; //to translate
$strUsersHavingAccessToDb = 'Users having access to &quot;%s&quot;'; //to translate
$strUseTextField = 'Use text field'; //to translate
$strUseThisValue = 'Use this value'; //to translate

$strValidatorError = 'The SQL validator could not be initialized. Please check if you have installed the necessary php extensions as described in the %sdocumentation%s.'; //to translate
$strVar = 'Variable'; //to translate
$strViewDumpDatabases = 'View dump (schema) of databases'; //to translate

$strWebServerUploadDirectory = 'web-server upload directory'; //to translate
$strWestEuropean = 'West European'; //to translate
$strWildcard = 'wildcard'; //to translate
$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings'; //to translate
$strWritingCommentNotPossible = 'Writing of comment not possible'; //to translate
$strWritingRelationNotPossible = 'Writing of relation not possible'; //to translate

$strXML = 'XML'; //to translate

$strZeroRemovesTheLimit = 'Note: Setting these options to 0 (zero) removes the limit.'; //to translate

$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
?>
